GoConqr has a new look! Let us know what you think.

Notes

La razón de ser de la economía.

maariafernandez Econ,Mates,Filo,CMC Spanish 1 page

Content of the notes (1)

Page 1

TEMA 1: La razón de ser de la economía.

1. ¿Qué es?

Ciencia que se ocupa de la forma en que se administran los recursos escasos para satisfacer las necesidades humanas.

Tipos de -Universal: Afecta a todos pero de distinta forma.

economía -Relativa: Los recursos disponibles son insuficientes relacionados con las necesidades.

2. Elegir es renunciar: el coste de oportunidad.

Ideas -Escasez económica: Recursos insuficientes para satisfacer necesidades.

clave -Necesidad de elegir: Administramos cuidadosamente los recursos para obtener el máximo provecho y elegimos lo que mas se ajusta a nuestras preferencias y nivel de ingresos.

-Coste de oportunidad: Valor medido o no en dinero de aquello a lo que se renuncia al tomar una decisión, valor de lo que no elegiste.

3. Necesidades, bienes y servicios.

-Necesidad: Deseo de satisfacer algo de lo que se carece, no todas son iguales.

Tipos de -Primarias: Imprescindibles.

necesidades -Secundarias: Más prescindibles y dependen de la época y la cultura.

-Bienes (materiales) y servicios (inmateriales) : Satisfacen necesidades humanas.

Según -Consumo: Satisfacen directamente las necesidades humanas.

función -Capital: Necesarias para realizar una actividad productiva. Permiten fabricar otros bienes.

Según grado -Libres: Ilimitados.

escasez -Económicas: Tienen un precio por ser útiles, escasos y transferibles, han de ser administrados.

Según grado -Intermedios: No son capaces de satisfacer las necesidades para las que fueron creados. Deben transformarse.

transformación -Finales: Preparados para ser utilizados o consumidos.

Acceso a -Públicos: Ninguna persona es excluida de su utilización.

bienes -Privados: Solo los disfruta el que paga por ello.

4. Actividades económicas: consumo, producción y distribución.

-Actividades económicas: Hay que elegir renunciando a lo que no se escoge.

Actividades -Consumo: Decidir como repartir los ingresos para satisfacer las necesidades de acuerdo con las preferencias.

económicas -Producción: Empresas deciden que bienes les compensa elaborar y que recursos necesitan para ello. Compara costes y beneficios, escoge la mejor alternativa.

-Distribución: Nexo entre consumo y producción.

5. Los recursos productivos: Tierra, trabajo y capital.

-Recursos productivos: Elementos básicos empleados en la producción y distribución de bienes y servicios.

-Recursos naturales: Provienen de la naturaleza, preocupación por el agotamiento de los recursos no renovables.

Recursos -Trabajo: Actividad física o intelectual que interviene en el proceso productivo.

productivos -Bienes de capital: Son titularidad de la empresa.

-Iniciativa empresarial: Hay que saber organizar los recursos y dirigir a los trabajadores, funciones que recaen sobre el empresario.

6. Los agentes económicos.

Agentes -Economías domésticas: Consumidores deciden que bienes y servicios consumir.

económicos -Empresas: Toman decisiones sobre la producción y distribución.

-Sector público: Formado por administraciones públicas, su objetivo es conseguir el máximo bienestar para el conjunto de la sociedad.

Ramas -Microeconomía: Parte de la economía que analiza individualmente los agentes económicos, y las relaciones que tienen.

-Macroeconomía: Se ocupa de la economía en su conjunto.

-Modelo económico: Representación gráfica simplificada que ilustra o predice el comportamiento de una realidad compleja.

Nueva Página

Information

Description
Econ,Mates,Filo,CMC Note on La razón de ser de la economía., created by maariafernandez on 21/09/2014.
Created by
maariafernandez
Views
92
Rating

Feedback

What is it about?

What do you think of the new look?

How do you like it?